%global stackname common_msgs
%global gitrev 805193e
%global packages actionlib_msgs diagnostic_msgs geometry_msgs nav_msgs sensor_msgs stereo_msgs trajectory_msgs visualization_msgs

Name:		ros-%{rosrelease}-common-msgs
Version:	1.8.7
Release:	1%{?dist}
Summary:	ROS common messages
License:	BSD
URL:		http://ros.org/wiki/common_msgs
# wget --content-disposition https://github.com/wg-debs/common_msgs-release/tarball/upstream/1.8.7	
Source0:        wg-debs-%{stackname}-release-upstream-%{version}-0-g%{gitrev}.tar.gz

BuildRequires:	ros-%{rosrelease}-ros-devel, ros-%{rosrelease}-ros-comm-devel
BuildRequires:	cmake, python-yaml, yaml-cpp-devel, opencv-devel
BuildRequires:	chrpath
Provides:	ros-%{stackname} = %{version}-%{release}
Provides:       ros-common-msgs = %{version}-%{release}

%description
common_msgs contains messages that are widely used by other ROS
packages. These includes messages for actions (actionlib_msgs), diagnostics (diagnostic_msgs),
geometric primitives (geometry_msgs), robot navigation (nav_msgs), and common sensors
ensor_msgs), such as laser range finders, cameras, point clouds.

%package devel
Summary:	Development files for ROS common msgs
Requires:	ros-%{codename}-ros-devel, ros-%{codename}-ros-comm-devel
Requires:	%{name} = %{version}-%{release}
Provides:	ros-%{shortname}-devel = %{version}-%{release}
Provides:	ros-nodelet-core-devel = %{version}-%{release}

%description devel
Development files for ROS common msgs

%prep
%setup -q -c
# We have to do this so the cmake gunk can find itself. So idiotic.
mv %{shortname}-%{version} %{shortname}

%build
cd %{shortname}
source /etc/catkin/profile.d/10.ros.all
export ROS_PACKAGE_PATH="%{_builddir}/%{name}-%{version}:$ROS_PACKAGE_PATH"
for PKG in %{packages}; do
  pushd $PKG
  mkdir -p build
  cd build
  %cmake -DSETUPTOOLS_DEB_LAYOUT=OFF ..
  make %{?_smp_mflags}
  popd
done

%install
cd %{shortname}
mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/
cp -a stack.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/

#Loop through each package in the stack
for PKG in %{packages}; do
  pushd $PKG

  # Install the include dir, and any xml and dox files
  mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/$PKG
  for DIR in include cfg cmake docs  msg msg_gen srv srv_gen templates; do
  if [ -d $DIR ]; then
    cp -a $DIR %{buildroot}%{_datadir}/ros-stacks/%{shortname}/$PKG
  fi
  done


  if [ "`find ./ -name "*.xml" |head -n 1`" != ""  ]; then
    cp -a *.xml %{buildroot}%{_datadir}/ros-stacks/%{shortname}/$PKG
  fi
  if [ "`find ./ -name "*.dox" |head -n 1`" != ""  ]; then
    cp -a *.dox %{buildroot}%{_datadir}/ros-stacks/%{shortname}/$PKG
  fi
  if [ "`find ./ -name "__init__.py" |head -n 1`" != ""  ]; then
    mkdir -p %{buildroot}%{python_sitelib}
    cp -a src/$PKG %{buildroot}%{python_sitelib}/
  fi
  
  

  # Install stack binaries, create symlinks back to stack directory
  if [ -d bin ]; then
    mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/$PKG/bin
    mkdir -p %{buildroot}%{_bindir}
    
    for BIN in bin/*; do
      cp -a $BIN %{buildroot}%{_bindir}/ros-$(basename $BIN)
      ln -s %{_bindir}/ros-$(basename $BIN) %{buildroot}%{_datadir}/ros-stacks/%{shortname}/$PKG/$BIN
    done
  fi
  
  # Install stack libraries, create symlinks back to stack directory
  if [ -d lib ]; then
    mkdir -p %{buildroot}%{_datadir}/ros-stacks/%{shortname}/$PKG/lib
    mkdir -p %{buildroot}%{_libdir}
    
    for LIB in lib/*.so; do 
      cp -a $LIB %{buildroot}%{_libdir}/$(basename $LIB)
      ln -s %{_libdir}/$(basename $LIB) %{buildroot}%{_datadir}/ros-stacks/%{shortname}/$PKG/$LIB
    done
  fi
  popd
done

chrpath -d %{buildroot}%{_bindir}/*
chrpath -d %{buildroot}%{_libdir}/*.so

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{_bindir}/ros-nodelet
%{_datadir}/ros-stacks/%{shortname}/
%exclude %{_datadir}/ros-stacks/%{shortname}/nodelet/include/
%exclude %{_datadir}/ros-stacks/%{shortname}/nodelet_topic_tools/include/
%{_libdir}/libnodeletlib.so
%{_libdir}/libtest_nodelet_topic_tools.so
%{python_sitelib}/nodelet/
%{python_sitelib}/nodelet_topic_tools/

%files devel
%{_datadir}/ros-stacks/%{shortname}/nodelet/include/
%{_datadir}/ros-stacks/%{shortname}/nodelet_topic_tools/include/

%changelog
* Fri Jun 01 2012 Rich Mattes <rmattes@fedoraproject.org> - 1.6.5-1
- initial package
